pub enum DockerError {
BuildFailed {
image: String,
source: CommandError,
},
ListImagesFailed(CommandError),
ListContainersFailed(CommandError),
GetLogsFailed {
container_id: String,
source: CommandError,
},
}Expand description
Errors that can occur during Docker operations
Variants
BuildFailed
Docker build command failed
ListImagesFailed(CommandError)
Failed to list Docker images
ListContainersFailed(CommandError)
Failed to list Docker containers
GetLogsFailed
Failed to get container logs
Implementations
Sourceimpl DockerError
impl DockerError
Sourcepub fn help(&self) -> &'static str
pub fn help(&self) -> &'static str
Get detailed troubleshooting guidance for this error
This method provides comprehensive troubleshooting steps that can be displayed to users when they need more help resolving the error.
Example
use torrust_tracker_deployer_lib::adapters::docker::DockerClient;
let docker = DockerClient::new();
if let Err(e) = docker.build_image(".", "my-app", "latest") {
eprintln!("Error: {e}");
eprintln!("\nTroubleshooting:\n{}", e.help());
}Trait Implementations
Sourceimpl Debug for DockerError
impl Debug for DockerError
Sourceimpl Display for DockerError
impl Display for DockerError
Sourceimpl Error for DockerError
impl Error for DockerError
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()