pub enum NetworkError {
NetstatFailed(CommandError),
SsFailed(CommandError),
}Expand description
Errors that can occur during network diagnostic operations
Variants
NetstatFailed(CommandError)
Failed to execute netstat command
SsFailed(CommandError)
Failed to execute ss command
Implementations
Sourceimpl NetworkError
impl NetworkError
Sourcepub fn help(&self) -> &'static str
pub fn help(&self) -> &'static str
Get detailed troubleshooting guidance for this error
This method provides comprehensive troubleshooting steps that can be displayed to users when they need more help resolving the error.
Example
use torrust_tracker_deployer_lib::adapters::network::NetstatClient;
let netstat = NetstatClient::new();
if let Err(e) = netstat.list_tcp_listening_ports() {
eprintln!("Error: {e}");
eprintln!("\nTroubleshooting:\n{}", e.help());
}Trait Implementations
Sourceimpl Debug for NetworkError
impl Debug for NetworkError
Sourceimpl Display for NetworkError
impl Display for NetworkError
Sourceimpl Error for NetworkError
impl Error for NetworkError
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()