Module schema

Create Schema Command Handler

This module provides the command handler for generating JSON Schemas from the environment configuration types.

Structs

CreateSchemaCommandHandler
Handler for creating JSON Schema from configuration types

Enums

CreateSchemaCommandHandlerError
Errors that can occur during schema creation command handling