pub struct PrometheusInfo {
pub access_note: String,
}Expand description
Prometheus metrics service information for display purposes
This information shows the status of the Prometheus service when configured. Prometheus collects and stores metrics from the tracker service. It can be used independently or as a data source for Grafana.
Fields
access_note: StringDescription of how to access Prometheus (internal only)
Implementations
Sourceimpl PrometheusInfo
impl PrometheusInfo
Sourcepub fn default_internal() -> Self
pub fn default_internal() -> Self
Create default PrometheusInfo for standard deployment
Prometheus is always bound to localhost:9090 and not exposed externally.