pub struct RenderTrackerTemplatesStep<S> { /* private fields */ }Expand description
Step that renders Tracker configuration templates to the build directory
This step handles the preparation of Tracker configuration files
by rendering templates to the build directory. The rendered files are
then ready to be deployed to the remote host by the DeployTrackerConfigStep.
Implementations
Sourceimpl<S> RenderTrackerTemplatesStep<S>
impl<S> RenderTrackerTemplatesStep<S>
Sourcepub fn new(
environment: Arc<Environment<S>>,
templates_dir: PathBuf,
build_dir: PathBuf,
clock: Arc<dyn Clock>,
) -> Self
pub fn new( environment: Arc<Environment<S>>, templates_dir: PathBuf, build_dir: PathBuf, clock: Arc<dyn Clock>, ) -> Self
Creates a new RenderTrackerTemplatesStep
Arguments
environment- The deployment environmenttemplates_dir- The templates directorybuild_dir- The build directory where templates will be renderedclock- Clock service for generating timestamps
Sourcepub fn execute(&self) -> Result<PathBuf, TrackerTemplateRenderingServiceError>
pub fn execute(&self) -> Result<PathBuf, TrackerTemplateRenderingServiceError>