pub struct InstallDockerComposeStep { /* private fields */ }Expand description
Step that installs Docker Compose on a remote host via Ansible
Implementations
Sourceimpl InstallDockerComposeStep
impl InstallDockerComposeStep
pub fn new(ansible_client: Arc<AnsibleClient>) -> Self
Sourcepub fn execute(
&self,
listener: Option<&dyn CommandProgressListener>,
) -> Result<(), CommandError>
pub fn execute( &self, listener: Option<&dyn CommandProgressListener>, ) -> Result<(), CommandError>
Execute the Docker Compose installation step
This will run the “install-docker-compose” Ansible playbook to install Docker Compose on the remote host.
Arguments
listener- Optional progress listener for reporting step-level details. When provided, reports debug information (Ansible commands, working directory) and detail information (installation status, Compose version).
Errors
Returns an error if:
- The Ansible client fails to execute the playbook
- Docker Compose installation fails
- The playbook execution fails for any other reason