pub struct ProfileName(/* private fields */);Expand description
A validated LXD profile name following LXD naming requirements.
Valid profile names must fulfill the following requirements:
- The name must be between 1 and 63 characters long
- The name must contain only letters, numbers and dashes from the ASCII table
- The name must not start with a digit or a dash
- The name must not end with a dash
These requirements ensure that the profile name can be used in DNS records, on the file system, in various security profiles and as the host name.
Examples
use torrust_tracker_deployer_lib::domain::ProfileName;
// Valid profile names - accepts both &str and String
let profile1 = ProfileName::new("test-profile")?;
let profile2 = ProfileName::new("web-server-profile".to_string())?;
let profile3 = ProfileName::new(format!("app-{}-profile", "prod"))?;
// Invalid profile names
assert!(ProfileName::new("").is_err());
assert!(ProfileName::new("test-").is_err());
assert!(ProfileName::new("-test").is_err());
assert!(ProfileName::new("1test").is_err());Implementations
Sourceimpl ProfileName
impl ProfileName
Sourcepub fn new<S: Into<String>>(name: S) -> Result<Self, ProfileNameError>
pub fn new<S: Into<String>>(name: S) -> Result<Self, ProfileNameError>
Creates a new ProfileName from a string if it’s valid.
Arguments
name- The profile name to validate (accepts&str,String, or anything that implementsInto<String>)
Returns
Ok(ProfileName)- If the name is validErr(ProfileNameError)- If the name violates LXD naming requirements
Errors
This function will return an error if the name violates any LXD naming requirements:
- Empty name
- Name longer than 63 characters
- Name contains non-ASCII letters, numbers, or dashes
- Name starts with a digit or dash
- Name ends with a dash
Examples
use torrust_tracker_deployer_lib::domain::ProfileName;
// Valid names - accepts both &str and String
let name1 = ProfileName::new("test-profile")?;
let name2 = ProfileName::new("web-01-profile".to_string())?;
let name3 = ProfileName::new(format!("app-{}-profile", "prod"))?;
// Invalid names
assert!(ProfileName::new("").is_err());
assert!(ProfileName::new("test-").is_err());
assert!(ProfileName::new("-test").is_err());
assert!(ProfileName::new("1test").is_err());Trait Implementations
Sourceimpl AsRef<str> for ProfileName
impl AsRef<str> for ProfileName
Sourceimpl Clone for ProfileName
impl Clone for ProfileName
Sourceimpl Debug for ProfileName
impl Debug for ProfileName
Sourceimpl<'de> Deserialize<'de> for ProfileName
impl<'de> Deserialize<'de> for ProfileName
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ProfileName
impl Display for ProfileName
impl Eq for ProfileName
Sourceimpl From<ProfileName> for String
impl From<ProfileName> for String
Sourcefn from(profile_name: ProfileName) -> Self
fn from(profile_name: ProfileName) -> Self
Converts to this type from the input type.
Sourceimpl FromStr for ProfileName
impl FromStr for ProfileName
Sourceimpl Hash for ProfileName
impl Hash for ProfileName
Sourceimpl PartialEq for ProfileName
impl PartialEq for ProfileName
Sourceimpl Serialize for ProfileName
impl Serialize for ProfileName
impl StructuralPartialEq for ProfileName