pub struct TemplateEngine { /* private fields */ }Expand description
Template processing engine for validation and rendering
Implementations
Sourceimpl TemplateEngine
impl TemplateEngine
Sourcepub fn render<T: Serialize>(
&mut self,
template_name: &str,
template_content: &str,
context: &T,
) -> Result<String, TemplateEngineError>
pub fn render<T: Serialize>( &mut self, template_name: &str, template_content: &str, context: &T, ) -> Result<String, TemplateEngineError>
Creates a new TemplateEngine with template content and validates it with the given context
This method combines template creation and validation to ensure templates are always instantiated in a valid state. It will fail if:
- Template has syntax errors
- Template references undefined variables
- Template cannot be rendered for any reason
Errors
Returns an error if template content cannot be parsed or validation fails