pub enum FileOperationError {
DirectoryCreation {
path: String,
},
FileWrite {
path: String,
},
FileCopy {
source_path: String,
dest_path: String,
},
}Expand description
Errors that can occur during file operations
Variants
DirectoryCreation
Failed to create the output directory
FileWrite
Failed to write the file to the output path
FileCopy
Failed to copy the file from source to destination