pub enum DatabaseConfig {
Sqlite(SqliteConfig),
Mysql(MysqlConfig),
}Expand description
Database configuration for Tracker
Supports multiple database backends. Currently implemented:
SQLite(file-based, development and small deployments)MySQL(planned for production deployments)
Examples
use torrust_tracker_deployer_lib::domain::tracker::{DatabaseConfig, SqliteConfig};
// SQLite configuration
let sqlite = DatabaseConfig::Sqlite(SqliteConfig::new("tracker.db").unwrap());
// MySQL configuration
// use torrust_tracker_deployer_lib::domain::tracker::MysqlConfig;
// use torrust_tracker_deployer_lib::shared::Password;
// let mysql = DatabaseConfig::Mysql(MysqlConfig::new(
// "localhost", 3306, "tracker", "tracker_user", Password::from("secure_password")
// ).unwrap());Variants
Implementations
Sourceimpl DatabaseConfig
impl DatabaseConfig
Sourcepub fn driver_name(&self) -> &str
pub fn driver_name(&self) -> &str
Returns the database driver name
Examples
use torrust_tracker_deployer_lib::domain::tracker::{DatabaseConfig, SqliteConfig};
let config = DatabaseConfig::Sqlite(SqliteConfig::new("tracker.db").unwrap());
assert_eq!(config.driver_name(), "sqlite3");Sourcepub fn database_name(&self) -> &str
pub fn database_name(&self) -> &str
Returns the database name
Examples
use torrust_tracker_deployer_lib::domain::tracker::{DatabaseConfig, SqliteConfig};
let config = DatabaseConfig::Sqlite(SqliteConfig::new("tracker.db").unwrap());
assert_eq!(config.database_name(), "tracker.db");Sourcepub fn docker_image(&self) -> Option<DockerImage>
pub fn docker_image(&self) -> Option<DockerImage>
Returns the Docker image for the database service container, if applicable.
Mysqlvariant returns theMySQLdocker imageSqlitereturnsNone—SQLiteruns in-process; no container is needed
Examples
use torrust_tracker_deployer_lib::domain::tracker::{DatabaseConfig, SqliteConfig, MysqlConfig};
use torrust_tracker_deployer_lib::shared::Password;
let sqlite = DatabaseConfig::Sqlite(SqliteConfig::new("tracker.db").unwrap());
assert!(sqlite.docker_image().is_none());
let mysql = DatabaseConfig::Mysql(
MysqlConfig::new("localhost", 3306, "tracker", "user", "pass".to_string().into(), "root_pass".to_string().into()).unwrap()
);
assert_eq!(mysql.docker_image().unwrap().full_reference(), "mysql:8.4");Trait Implementations
Sourceimpl Clone for DatabaseConfig
impl Clone for DatabaseConfig
Sourceimpl Debug for DatabaseConfig
impl Debug for DatabaseConfig
Sourceimpl<'de> Deserialize<'de> for DatabaseConfig
impl<'de> Deserialize<'de> for DatabaseConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DatabaseConfig
impl PartialEq for DatabaseConfig
Sourceimpl Serialize for DatabaseConfig
impl Serialize for DatabaseConfig
impl StructuralPartialEq for DatabaseConfig
Sourceimpl TryFrom<DatabaseSection> for DatabaseConfig
impl TryFrom<DatabaseSection> for DatabaseConfig
Sourcetype Error = CreateConfigError
type Error = CreateConfigError
The type returned in the event of a conversion error.