pub struct TemplateMetadata { /* private fields */ }Expand description
Metadata about template generation.
This struct is designed to be flattened into template contexts using #[serde(flatten)],
making the timestamp available at the top level in templates.
Example
use torrust_tracker_deployer_lib::infrastructure::templating::metadata::TemplateMetadata;
use chrono::{TimeZone, Utc};
let timestamp = Utc.with_ymd_and_hms(2026, 1, 27, 14, 30, 0).unwrap();
let metadata = TemplateMetadata::new(timestamp);
assert_eq!(metadata.generated_at(), ×tamp);Implementations
Sourceimpl TemplateMetadata
impl TemplateMetadata
Sourcepub fn new(generated_at: DateTime<Utc>) -> Self
pub fn new(generated_at: DateTime<Utc>) -> Self
Creates a new TemplateMetadata with the given timestamp.
Arguments
generated_at- UTC timestamp when the template was generated
Example
use torrust_tracker_deployer_lib::infrastructure::templating::metadata::TemplateMetadata;
use chrono::{TimeZone, Utc};
let timestamp = Utc.with_ymd_and_hms(2026, 1, 27, 14, 30, 0).unwrap();
let metadata = TemplateMetadata::new(timestamp);Sourcepub fn generated_at(&self) -> &DateTime<Utc>
pub fn generated_at(&self) -> &DateTime<Utc>
Returns the generation timestamp.
Example
use torrust_tracker_deployer_lib::infrastructure::templating::metadata::TemplateMetadata;
use chrono::{TimeZone, Utc};
let timestamp = Utc.with_ymd_and_hms(2026, 1, 27, 14, 30, 0).unwrap();
let metadata = TemplateMetadata::new(timestamp);
assert_eq!(metadata.generated_at(), ×tamp);Sourcepub fn generated_at_iso8601(&self) -> String
pub fn generated_at_iso8601(&self) -> String
Returns the timestamp formatted as ISO 8601 string.
Format: YYYY-MM-DDTHH:MM:SSZ (e.g., 2026-01-27T14:30:00Z)
Example
use torrust_tracker_deployer_lib::infrastructure::templating::metadata::TemplateMetadata;
use chrono::{TimeZone, Utc};
let timestamp = Utc.with_ymd_and_hms(2026, 1, 27, 14, 30, 0).unwrap();
let metadata = TemplateMetadata::new(timestamp);
assert_eq!(metadata.generated_at_iso8601(), "2026-01-27T14:30:00Z");Trait Implementations
Sourceimpl Clone for TemplateMetadata
impl Clone for TemplateMetadata
Sourceimpl Debug for TemplateMetadata
impl Debug for TemplateMetadata
Sourceimpl<'de> Deserialize<'de> for TemplateMetadata
impl<'de> Deserialize<'de> for TemplateMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TemplateMetadata
Sourceimpl PartialEq for TemplateMetadata
impl PartialEq for TemplateMetadata
Sourceimpl Serialize for TemplateMetadata
impl Serialize for TemplateMetadata
impl StructuralPartialEq for TemplateMetadata