pub struct ResultMessage {
pub text: String,
}Expand description
Result message for final output data
Result messages contain final output data that can be piped or redirected. They go to stdout without any symbols or formatting.
Fields
text: StringThe result message text