Module command

Module command 

Command execution utilities with error handling and logging

This module provides utilities for executing external commands with proper error handling, logging, and output capture. It supports both verbose and quiet execution modes and provides structured error types for different failure scenarios.

Key Features

  • Structured error handling with detailed context
  • Optional verbose output logging
  • Working directory support
  • Comprehensive error categorization (startup vs execution failures)

Re-exports

pub use error::CommandError;
pub use executor::CommandExecutor;
pub use result::CommandResult;

Modules

error
Command execution error types
executor
Command execution utilities
result
Command execution result