Module result

Module result 

Command execution result

This module provides the CommandResult struct that represents the complete result of a successfully executed command, including exit status, stdout, and stderr.

Structs

CommandResult
Represents the complete result of a successfully executed command