pub struct Email(/* private fields */);Expand description
A validated email address
This type wraps the email_address crate to provide RFC-compliant
email validation. It can be used in domain entities where email
addresses are required.
Validation
The email address must conform to RFC 5321/5322 standards:
- Must have a local part and domain separated by
@ - Local part can contain alphanumeric characters and some special characters
- Domain must be a valid domain name or IP address
Examples
use torrust_tracker_deployer_types::Email;
let email = Email::new("user@example.com").unwrap();
println!("Email: {}", email);Implementations
Sourceimpl Email
impl Email
Sourcepub fn new(email: &str) -> Result<Email, EmailError>
pub fn new(email: &str) -> Result<Email, EmailError>
Creates a new validated email address
Arguments
email- The email address string to validate
Returns
Ok(Email)- If the email is validErr(EmailError)- If the email is invalid
Errors
Returns EmailError::InvalidFormat if the email doesn’t comply with
RFC 5321/5322 standards.
Examples
use torrust_tracker_deployer_types::Email;
let valid = Email::new("admin@example.com");
assert!(valid.is_ok());
let invalid = Email::new("not-an-email");
assert!(invalid.is_err());Sourcepub fn local_part(&self) -> &str
pub fn local_part(&self) -> &str
Returns the local part of the email (before the @)
Examples
use torrust_tracker_deployer_types::Email;
let email = Email::new("user@example.com").unwrap();
assert_eq!(email.local_part(), "user");Sourcepub fn domain_part(&self) -> &str
pub fn domain_part(&self) -> &str
Returns the domain part of the email (after the @)
Examples
use torrust_tracker_deployer_types::Email;
let email = Email::new("user@example.com").unwrap();
assert_eq!(email.domain_part(), "example.com");Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Email
impl<'de> Deserialize<'de> for Email
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Email, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Email, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Email
impl JsonSchema for Email
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for Email
impl Serialize for Email
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for Email
impl StructuralPartialEq for Email