pub struct Username(/* private fields */);Expand description
A validated Linux system username following Linux naming requirements.
Valid usernames must fulfill the following requirements:
- The username must be between 1 and 32 characters long
- The username must start with a letter (a-z, A-Z) or underscore (_)
- The username can contain lowercase letters, digits, underscores, and hyphens
- The username cannot contain spaces or other special characters
These requirements ensure that the username can be used for:
- SSH authentication
- File and directory ownership
- Process ownership and management
- System user identification
Implementations
Sourceimpl Username
impl Username
Sourcepub fn new<S>(username: S) -> Result<Username, UsernameError>
pub fn new<S>(username: S) -> Result<Username, UsernameError>
Creates a new Username from a string if it’s valid.
Arguments
username- The username to validate (accepts&str,String, or anything that implementsInto<String>)
Returns
Ok(Username)- If the username is validErr(UsernameError)- If the username violates Linux naming requirements
Errors
This function will return an error if the username violates any Linux naming requirements:
- Empty username
- Username longer than 32 characters
- Username contains invalid characters
- Username starts with a digit or invalid character
Examples
use torrust_tracker_deployer_types::Username;
// Valid usernames - accepts both &str and String
let user1 = Username::new("torrust")?;
let user2 = Username::new("user_123".to_string())?;
let user3 = Username::new("deploy-user")?;
let user4 = Username::new("_service")?;
// Invalid usernames
assert!(Username::new("").is_err());
assert!(Username::new("user@domain").is_err());
assert!(Username::new("123user").is_err());Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Username
impl<'de> Deserialize<'de> for Username
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Username, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Username, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Username
Sourceimpl Serialize for Username
impl Serialize for Username
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for Username