pub struct Services {
pub opentofu_client: Arc<OpenTofuClient>,
pub lxd_client: Arc<LxdClient>,
pub ansible_client: Arc<AnsibleClient>,
pub template_manager: Arc<TemplateManager>,
pub tofu_template_renderer: Arc<TofuProjectGenerator>,
pub ansible_project_generator: Arc<AnsibleProjectGenerator>,
pub clock: Arc<dyn Clock>,
pub file_repository_factory: Arc<FileRepositoryFactory>,
}Expand description
Service clients and renderers for performing actions in tests
Fields
opentofu_client: Arc<OpenTofuClient>lxd_client: Arc<LxdClient>ansible_client: Arc<AnsibleClient>template_manager: Arc<TemplateManager>tofu_template_renderer: Arc<TofuProjectGenerator>ansible_project_generator: Arc<AnsibleProjectGenerator>clock: Arc<dyn Clock>Clock service for testable time management
file_repository_factory: Arc<FileRepositoryFactory>Factory for creating environment-specific repositories
Implementations
Sourceimpl Services
impl Services
Sourcepub fn new(
config: &Config,
ssh_credentials: SshCredentials,
instance_name: InstanceName,
provider_config: ProviderConfig,
) -> Self
pub fn new( config: &Config, ssh_credentials: SshCredentials, instance_name: InstanceName, provider_config: ProviderConfig, ) -> Self
Create a new services container using the provided configuration