Module executor

Module executor 

Container Command Executor Trait

This module defines the trait that allows decoupled container actions to execute commands inside running containers.

Traits

ContainerExecutor
Trait for containers that can execute commands inside themselves