ContainerImageBuilder

Struct ContainerImageBuilder 

pub struct ContainerImageBuilder { /* private fields */ }
Builder for constructing and building container images

This builder follows the standard Rust builder pattern, allowing method chaining to configure container image build parameters.

Required Values

The following values must be provided before calling build():

  • Image name: Must be set with with_name()
  • Dockerfile path: Must be set with with_dockerfile()

Default Values

  • Tag: “latest”
  • Build context: “.” (current directory)
  • Build timeout: 300 seconds

Implementations

Source

impl ContainerImageBuilder

pub fn new() -> Self

Create a new container image builder with default configuration

Examples
use torrust_tracker_deployer_lib::testing::e2e::containers::ContainerImageBuilder;

let builder = ContainerImageBuilder::new();
pub fn with_name(self, name: impl Into<String>) -> Self

Set the container image name

Arguments
  • name - The container image name
Examples
use torrust_tracker_deployer_lib::testing::e2e::containers::ContainerImageBuilder;

let builder = ContainerImageBuilder::new()
    .with_name("my-custom-image");
pub fn with_tag(self, tag: impl Into<String>) -> Self

Set the container image tag

Arguments
  • tag - The container image tag
Examples
use torrust_tracker_deployer_lib::testing::e2e::containers::ContainerImageBuilder;

let builder = ContainerImageBuilder::new()
    .with_tag("v1.0.0");
pub fn with_dockerfile(self, path: PathBuf) -> Self

Set the path to the Dockerfile

Arguments
  • path - Path to the Dockerfile
Examples
use torrust_tracker_deployer_lib::testing::e2e::containers::ContainerImageBuilder;
use std::path::PathBuf;

let builder = ContainerImageBuilder::new()
    .with_dockerfile(PathBuf::from("custom/Dockerfile"));
pub fn with_context(self, path: PathBuf) -> Self

Set the Docker build context path

Arguments
  • path - Path to the build context directory
Examples
use torrust_tracker_deployer_lib::testing::e2e::containers::ContainerImageBuilder;
use std::path::PathBuf;

let builder = ContainerImageBuilder::new()
    .with_context(PathBuf::from("./app"));
pub fn with_build_timeout(self, timeout: Duration) -> Self

Set the build timeout duration

Arguments
  • timeout - Maximum time to wait for build completion
Examples
use torrust_tracker_deployer_lib::testing::e2e::containers::ContainerImageBuilder;
use std::time::Duration;

let builder = ContainerImageBuilder::new()
    .with_build_timeout(Duration::from_secs(600));
pub fn build(&self) -> Result<()>

Build the container image using the configured parameters

This method executes the docker build command with the configured parameters. It provides detailed error information if the build fails.

Errors

Returns an error if:

  • Image name was not provided (use with_name())
  • Dockerfile path was not provided (use with_dockerfile())
  • Docker command cannot be executed (e.g., Docker not installed)
  • Docker build process fails (non-zero exit code)
Examples
use torrust_tracker_deployer_lib::testing::e2e::containers::ContainerImageBuilder;
use std::path::PathBuf;

let builder = ContainerImageBuilder::new()
    .with_name("my-image")
    .with_dockerfile(PathBuf::from("Dockerfile"));
builder.build()?;
pub fn image_tag(&self) -> String

Get the full image tag (name:tag) that will be used for the build

Panics

Panics if image name has not been set. Use with_name() first.

Examples
use torrust_tracker_deployer_lib::testing::e2e::containers::ContainerImageBuilder;

let builder = ContainerImageBuilder::new()
    .with_name("my-app")
    .with_tag("v1.0");
     
assert_eq!(builder.image_tag(), "my-app:v1.0");
pub fn image_name(&self) -> Option<&str>

Get the image name if it has been set

pub fn tag(&self) -> &str

Get the image tag

pub fn dockerfile_path(&self) -> Option<&PathBuf>

Get the dockerfile path if it has been set

pub fn context_path(&self) -> &PathBuf

Get the build context path

pub fn build_timeout(&self) -> Duration

Get the build timeout