pub struct RunningProvisionedContainer { /* private fields */ }Expand description
Running state - container is started and can be configured
Implementations
Sourceimpl RunningProvisionedContainer
impl RunningProvisionedContainer
Sourcepub fn ssh_socket_addr(&self) -> SocketAddr
pub fn ssh_socket_addr(&self) -> SocketAddr
Get the SSH connection details
Sourcepub fn additional_mapped_ports(&self) -> &[u16]
pub fn additional_mapped_ports(&self) -> &[u16]
Get the mapped additional ports (tracker API, HTTP tracker, UDP tracker, etc.) Returns ports in the same order they were requested when starting the container
Sourcepub fn container_id(&self) -> &str
pub fn container_id(&self) -> &str
Get the container ID for logging/debugging
Sourcepub fn stop(self) -> StoppedProvisionedContainer
pub fn stop(self) -> StoppedProvisionedContainer
Stop the container and transition back to stopped state