pub struct StoppedProvisionedContainer {
pub timeouts: ContainerTimeouts,
}Expand description
Container configuration following state machine pattern
Following the pattern from Torrust Tracker MySQL driver, where different states
have different capabilities enforced at compile time.
Initial state - container is stopped/not started yet
Fields
timeouts: ContainerTimeoutsTimeout configurations for container operations
Implementations
Sourceimpl StoppedProvisionedContainer
impl StoppedProvisionedContainer
Sourcepub fn with_timeouts(timeouts: ContainerTimeouts) -> Self
pub fn with_timeouts(timeouts: ContainerTimeouts) -> Self
Create a new stopped container with custom timeout configurations
Arguments
timeouts- Custom timeout configuration for container operations
Example
use torrust_tracker_deployer_lib::testing::e2e::containers::{StoppedProvisionedContainer, ContainerTimeouts};
use std::time::Duration;
let mut timeouts = ContainerTimeouts::default();
timeouts.ssh_ready = Duration::from_secs(60);
let container = StoppedProvisionedContainer::with_timeouts(timeouts);Sourcepub fn with_ssh_ready_timeout(ssh_ready_timeout: Duration) -> Self
pub fn with_ssh_ready_timeout(ssh_ready_timeout: Duration) -> Self
Create a new stopped container with custom SSH ready timeout
This is a convenience method for the most commonly customized timeout.
Arguments
ssh_ready_timeout- How long to wait for SSH to become available
Example
use torrust_tracker_deployer_lib::testing::e2e::containers::StoppedProvisionedContainer;
use std::time::Duration;
let container = StoppedProvisionedContainer::with_ssh_ready_timeout(
Duration::from_secs(60)
);Sourcepub async fn start(
self,
container_name: Option<String>,
ssh_port: u16,
additional_ports: &[u16],
) -> Result<RunningProvisionedContainer>
pub async fn start( self, container_name: Option<String>, ssh_port: u16, additional_ports: &[u16], ) -> Result<RunningProvisionedContainer>
Start the container and transition to running state
Arguments
container_name- Optional name for the running container. If provided, the container will be named accordingly.ssh_port- The internal SSH port to expose from the containeradditional_ports- Additional TCP ports to expose (e.g., tracker API, HTTP tracker)
Errors
Returns an error if:
- Docker image build fails
- Container fails to start
- Container networking setup fails