Module container

Module container 

Container-specific E2E tasks

This module contains tasks that are specifically designed for container-based E2E testing using Docker containers instead of VMs. These tasks handle the unique requirements and workflows when using testcontainers for testing infrastructure deployment.

Tasks Overview

  • cleanup_infrastructure - Stops and cleans up Docker containers after testing
  • preflight_cleanup - Container-specific preflight cleanup operations

Modules

cleanup_infrastructure
Container management task for E2E testing
preflight_cleanup
Container-specific preflight cleanup functionality