Module virtual_machine

Module virtual_machine 

Virtual machine-specific E2E tasks

This module contains tasks that are specifically designed for VM-based E2E testing using LXD virtual machines. These tasks handle the unique requirements and workflows when using OpenTofu and LXD for production-like infrastructure provisioning.

Modules

cleanup_infrastructure
Infrastructure cleanup task for E2E testing
preflight_cleanup
Virtual machine-specific preflight cleanup functionality
run_destroy_command
Infrastructure destruction task for E2E testing
run_provision_command
Infrastructure provisioning task for E2E testing