pub enum ReleaseWorkflowStep {
Show 19 variants
CreateTrackerStorage,
InitTrackerDatabase,
RenderTrackerTemplates,
DeployTrackerConfigToRemote,
CreatePrometheusStorage,
RenderPrometheusTemplates,
DeployPrometheusConfigToRemote,
CreateGrafanaStorage,
RenderGrafanaTemplates,
DeployGrafanaProvisioning,
CreateMysqlStorage,
RenderBackupTemplates,
CreateBackupStorage,
DeployBackupConfigToRemote,
InstallBackupCrontab,
RenderCaddyTemplates,
DeployCaddyConfigToRemote,
RenderDockerComposeTemplates,
DeployComposeFilesToRemote,
}Expand description
Application-layer representation of a release workflow step.
Mirrors crate::domain::environment::state::ReleaseStep for error
reporting in ReleaseCommandHandlerError variants that need to surface
the step that failed. SDK consumers can display or match on these variants
without importing the domain module.
Examples
use torrust_tracker_deployer_lib::application::errors::ReleaseWorkflowStep;
let step = ReleaseWorkflowStep::InitTrackerDatabase;
assert_eq!(step.to_string(), "Initialize Tracker Database");Variants
CreateTrackerStorage
Creating tracker storage directories on remote host
InitTrackerDatabase
Initializing tracker SQLite database file
RenderTrackerTemplates
Rendering Tracker configuration templates to the build directory
DeployTrackerConfigToRemote
Deploying tracker configuration to the remote host via Ansible
CreatePrometheusStorage
Creating Prometheus storage directories on remote host
RenderPrometheusTemplates
Rendering Prometheus configuration templates to the build directory
DeployPrometheusConfigToRemote
Deploying Prometheus configuration to the remote host via Ansible
CreateGrafanaStorage
Creating Grafana storage directories on remote host
RenderGrafanaTemplates
Rendering Grafana provisioning templates to the build directory
DeployGrafanaProvisioning
Deploying Grafana provisioning configuration to the remote host via Ansible
CreateMysqlStorage
Creating MySQL storage directories on remote host
RenderBackupTemplates
Rendering Backup configuration templates to the build directory
CreateBackupStorage
Creating Backup storage directories on remote host
DeployBackupConfigToRemote
Deploying Backup configuration to the remote host via Ansible
InstallBackupCrontab
Installing backup crontab and maintenance script
RenderCaddyTemplates
Rendering Caddy configuration templates to the build directory
DeployCaddyConfigToRemote
Deploying Caddy configuration to the remote host via Ansible
RenderDockerComposeTemplates
Rendering Docker Compose templates to the build directory
DeployComposeFilesToRemote
Deploying compose files to the remote host via Ansible