pub struct TrackerConfig { /* private fields */ }Expand description
Tracker deployment configuration
This structure mirrors the real tracker configuration but only includes user-configurable fields that are exposed via the environment.json file.
Examples
use torrust_tracker_deployer_lib::domain::tracker::{
TrackerConfig, TrackerCoreConfig, DatabaseConfig, SqliteConfig,
UdpTrackerConfig, HttpTrackerConfig, HttpApiConfig, HealthCheckApiConfig
};
let tracker_config = TrackerConfig::new(
TrackerCoreConfig::new(
DatabaseConfig::Sqlite(SqliteConfig::new("tracker.db").unwrap()),
false,
),
vec![UdpTrackerConfig::new("0.0.0.0:6969".parse().unwrap(), None).unwrap()],
vec![HttpTrackerConfig::new("0.0.0.0:7070".parse().unwrap(), None, false).unwrap()],
HttpApiConfig::new(
"0.0.0.0:1212".parse().unwrap(),
"MyAccessToken".to_string().into(),
None,
false,
).expect("valid config"),
HealthCheckApiConfig::new(
"127.0.0.1:1313".parse().unwrap(),
None,
false,
).expect("valid config"),
).expect("valid config");Implementations
Sourceimpl TrackerConfig
impl TrackerConfig
Sourcepub fn new(
core: TrackerCoreConfig,
udp_trackers: Vec<UdpTrackerConfig>,
http_trackers: Vec<HttpTrackerConfig>,
http_api: HttpApiConfig,
health_check_api: HealthCheckApiConfig,
) -> Result<Self, TrackerConfigError>
pub fn new( core: TrackerCoreConfig, udp_trackers: Vec<UdpTrackerConfig>, http_trackers: Vec<HttpTrackerConfig>, http_api: HttpApiConfig, health_check_api: HealthCheckApiConfig, ) -> Result<Self, TrackerConfigError>
Creates a new TrackerConfig with validated aggregate invariants.
This constructor validates that no socket address conflicts exist (multiple services binding to the same IP:port:protocol combination).
Errors
Returns TrackerConfigError::DuplicateSocketAddress if multiple services
using the same protocol attempt to bind to the same socket address.
Note
Individual component validation (port != 0, TLS requires domain, localhost cannot use TLS) is enforced by the child config types at their construction time. This constructor only validates aggregate-level invariants.
Examples
use torrust_tracker_deployer_lib::domain::tracker::{
TrackerConfig, TrackerCoreConfig, DatabaseConfig, SqliteConfig,
UdpTrackerConfig, HttpTrackerConfig, HttpApiConfig, HealthCheckApiConfig
};
let config = TrackerConfig::new(
TrackerCoreConfig::new(
DatabaseConfig::Sqlite(SqliteConfig::new("tracker.db").unwrap()),
false,
),
vec![UdpTrackerConfig::new("0.0.0.0:6969".parse().unwrap(), None).unwrap()],
vec![HttpTrackerConfig::new("0.0.0.0:7070".parse().unwrap(), None, false).unwrap()],
HttpApiConfig::new(
"0.0.0.0:1212".parse().unwrap(),
"MyAccessToken".to_string().into(),
None,
false,
).unwrap(),
HealthCheckApiConfig::new(
"127.0.0.1:1313".parse().unwrap(),
None,
false,
).unwrap(),
).expect("valid config");Sourcepub fn core(&self) -> &TrackerCoreConfig
pub fn core(&self) -> &TrackerCoreConfig
Returns the core tracker configuration.
Sourcepub fn udp_trackers(&self) -> &[UdpTrackerConfig]
pub fn udp_trackers(&self) -> &[UdpTrackerConfig]
Returns the UDP tracker configurations.
Sourcepub fn http_trackers(&self) -> &[HttpTrackerConfig]
pub fn http_trackers(&self) -> &[HttpTrackerConfig]
Returns the HTTP tracker configurations.
Sourcepub fn http_api(&self) -> &HttpApiConfig
pub fn http_api(&self) -> &HttpApiConfig
Returns the HTTP API configuration.
Sourcepub fn health_check_api(&self) -> &HealthCheckApiConfig
pub fn health_check_api(&self) -> &HealthCheckApiConfig
Returns the Health Check API configuration.
Sourcepub fn uses_mysql(&self) -> bool
pub fn uses_mysql(&self) -> bool
Returns whether the tracker is configured to use MySQL database.
This is useful for determining if MySQL-related infrastructure (like storage directories) needs to be created.
Examples
use torrust_tracker_deployer_lib::domain::tracker::{
TrackerConfig, TrackerCoreConfig, DatabaseConfig, SqliteConfig,
UdpTrackerConfig, HttpTrackerConfig, HttpApiConfig, HealthCheckApiConfig
};
let tracker_config = TrackerConfig::new(
TrackerCoreConfig::new(
DatabaseConfig::Sqlite(SqliteConfig::new("tracker.db").unwrap()),
false,
),
vec![UdpTrackerConfig::new("0.0.0.0:6969".parse().unwrap(), None).unwrap()],
vec![HttpTrackerConfig::new("0.0.0.0:7070".parse().unwrap(), None, false).unwrap()],
HttpApiConfig::new(
"0.0.0.0:1212".parse().unwrap(),
"MyAccessToken".to_string().into(),
None,
false,
).expect("valid config"),
HealthCheckApiConfig::new(
"127.0.0.1:1313".parse().unwrap(),
None,
false,
).expect("valid config"),
).expect("valid config");
// SQLite config -> not MySQL
assert!(!tracker_config.uses_mysql());Sourcepub fn docker_image() -> DockerImage
pub fn docker_image() -> DockerImage
Returns the Docker image used for the tracker service.
This is a pinned constant — not user-configurable.
Examples
use torrust_tracker_deployer_lib::domain::tracker::TrackerConfig;
let image = TrackerConfig::docker_image();
assert_eq!(image.full_reference(), "torrust/tracker:develop");Sourcepub fn http_api_tls_domain(&self) -> Option<&str>
pub fn http_api_tls_domain(&self) -> Option<&str>
Returns the HTTP API TLS domain if configured
Sourcepub fn http_api_port(&self) -> u16
pub fn http_api_port(&self) -> u16
Returns the HTTP API port number
Sourcepub fn health_check_api_tls_domain(&self) -> Option<&str>
pub fn health_check_api_tls_domain(&self) -> Option<&str>
Returns the Health Check API TLS domain if configured
Sourcepub fn health_check_api_port(&self) -> u16
pub fn health_check_api_port(&self) -> u16
Returns the Health Check API port number
Sourcepub fn http_trackers_with_tls(&self) -> Vec<(&str, u16)>
pub fn http_trackers_with_tls(&self) -> Vec<(&str, u16)>
Returns HTTP trackers that have TLS proxy enabled
Returns a vector of tuples containing (domain, port) for each
HTTP tracker that has use_tls_proxy: true and a domain configured.
Sourcepub fn any_http_tracker_uses_tls_proxy(&self) -> bool
pub fn any_http_tracker_uses_tls_proxy(&self) -> bool
Returns true if any HTTP tracker has use_tls_proxy: true
This is used to determine if the tracker’s global on_reverse_proxy
setting should be enabled in the tracker configuration template.
Sourcepub fn has_any_tls_configured(&self) -> bool
pub fn has_any_tls_configured(&self) -> bool
Returns true if any service has TLS proxy configured
Checks if at least one of the following services has TLS enabled:
- HTTP API (
use_tls_proxy: true) - Any HTTP tracker (
use_tls_proxy: true) - Health Check API (
use_tls_proxy: true)
This is used for cross-service validation to ensure that when the HTTPS section is defined, at least one service actually uses TLS.