pub trait RemoteAction {
// Required methods
fn name(&self) -> &'static str;
async fn execute(&self, server_ip: &IpAddr) -> Result<(), RemoteActionError>;
}Expand description
Trait for remote actions that can be executed on a server via SSH
Remote actions are lightweight scripts that connect to a provisioned server via SSH to perform various operations such as:
- Validating server state and configuration
- Retrieving server information (hostname, installed packages, etc.)
- Executing maintenance tasks (updates, cleanup, etc.)
- Installing or configuring software components
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".