Presentation Layer
This layer contains user-facing delivery mechanisms for the deployer application. It follows DDD architecture, separating presentation concerns from application and domain logic.
Module Structure
presentation/
└── cli/ # CLI delivery mechanism (Clap-based command-line interface)The SDK delivery mechanism has been extracted into the torrust-tracker-deployer-sdk
workspace package (packages/sdk/).
Re-exports
pub use cli::handle_error;pub use cli::Cli;pub use cli::CommandError;pub use cli::Commands;pub use cli::CreateCommandError;pub use cli::CreateEnvironmentCommandError;pub use cli::CreateEnvironmentTemplateCommandError;pub use cli::DestroySubcommandError;pub use cli::GlobalArgs;pub use cli::ProgressReporter;pub use cli::Theme;pub use cli::UserOutput;pub use cli::VerbosityLevel;
Modules
- cli
- CLI Delivery Mechanism