pub struct DebugDetailMessage {
pub text: String,
}Expand description
A debug detail message shown at Debug verbosity level and above
Debug detail messages provide technical implementation details during command execution, such as commands being executed, exit codes, and raw output from external tools.
Examples
ⓘ
use torrust_tracker_deployer_lib::presentation::cli::views::messages::DebugDetailMessage;
let message = DebugDetailMessage {
text: " → Command: tofu init".to_string(),
};Fields
text: StringThe debug detail text to display