pub struct FileSink { /* private fields */ }Expand description
Example: File sink that writes all output to a file
This is an example implementation showing how to create a custom sink that writes to a file. In production, you might want to add buffering, rotation, or other features.
Examples
ⓘ
use torrust_tracker_deployer_lib::presentation::cli::views::{FileSink, UserOutput, VerbosityLevel, CompositeSink, StandardSink};
// Write to both console and file
let composite = CompositeSink::new(vec![
Box::new(StandardSink::default_console()),
Box::new(FileSink::new("output.log").unwrap()),
]);
let mut output = UserOutput::with_sink(VerbosityLevel::Normal, Box::new(composite));Implementations