Container Command Executor Trait
This module defines the trait that allows decoupled container actions to execute commands inside running containers.
Traits
- Container
Executor - Trait for containers that can execute commands inside themselves