pub enum SshServerError {
DockerfileNotFound {
expected_path: PathBuf,
},
DockerBuildFailed {
image_name: String,
image_tag: String,
dockerfile_dir: String,
stdout: String,
stderr: String,
},
ContainerStartFailed {
source: TestcontainersError,
},
PortMappingFailed {
source: TestcontainersError,
},
DockerCommandFailed {
command: String,
source: Error,
},
InvalidUtf8InPath {
path: String,
},
DockerClientError {
source: Box<DockerError>,
},
}Expand description
Errors that can occur when working with SSH server containers
Variants
DockerfileNotFound
SSH server Dockerfile not found at expected location
DockerBuildFailed
Docker build command failed
ContainerStartFailed
Failed to start SSH server container
Fields

source: TestcontainersErrorPortMappingFailed
Failed to get mapped port for SSH container
Fields

source: TestcontainersErrorDockerCommandFailed
Docker command execution failed
InvalidUtf8InPath
Invalid UTF-8 in Dockerfile path
DockerClientError
Docker client operation failed
Fields

source: Box<DockerError>Implementations
Sourceimpl SshServerError
impl SshServerError
Sourcepub fn help(&self) -> &'static str
pub fn help(&self) -> &'static str
Get detailed troubleshooting guidance for this error
This method provides comprehensive troubleshooting steps that can be displayed to users when they need more help resolving the error.
Example
use torrust_tracker_deployer_lib::testing::integration::ssh_server::RealSshServerContainer;
if let Err(e) = RealSshServerContainer::start().await {
eprintln!("Error: {e}");
eprintln!("\nTroubleshooting:\n{}", e.help());
}Trait Implementations
Sourceimpl Debug for SshServerError
impl Debug for SshServerError
Sourceimpl Display for SshServerError
impl Display for SshServerError
Sourceimpl Error for SshServerError
impl Error for SshServerError
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()